@@ -1,7 +1,6 @@
 package chezmoi
 
 import (
-	"archive/zip"
 	"bytes"
 	"context"
 	"io"
@@ -9,9 +8,9 @@ import (
 	"testing"
 	"time"
 
+	"github.com/alecthomas/assert/v2"
 	"github.com/coreos/go-semver/semver"
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
+	"github.com/klauspost/compress/zip"
 	vfs "github.com/twpayne/go-vfs/v4"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoitest"
@@ -20,16 +19,16 @@ import (
 var _ System = &ZIPWriterSystem{}
 
 func TestZIPWriterSystem(t *testing.T) {
-	chezmoitest.WithTestFS(t, map[string]interface{}{
-		"/home/user/.local/share/chezmoi": map[string]interface{}{
+	chezmoitest.WithTestFS(t, map[string]any{
+		"/home/user/.local/share/chezmoi": map[string]any{
 			".chezmoiignore":  "README.md\n",
 			".chezmoiremove":  "*.txt\n",
 			".chezmoiversion": "1.2.3\n",
-			".chezmoitemplates": map[string]interface{}{
+			".chezmoitemplates": map[string]any{
 				"template": "# contents of .chezmoitemplates/template\n",
 			},
 			"README.md": "",
-			"dot_dir": map[string]interface{}{
+			"dot_dir": map[string]any{
 				"file": "# contents of .dir/file\n",
 			},
 			"run_script":      "# contents of script\n",
@@ -40,6 +39,7 @@ func TestZIPWriterSystem(t *testing.T) {
 		system := NewRealSystem(fileSystem)
 		s := NewSourceState(
 			WithBaseSystem(system),
+			WithDestDir(NewAbsPath("/home/user")),
 			WithSourceDir(NewAbsPath("/home/user/.local/share/chezmoi")),
 			WithSystem(system),
 			WithVersion(semver.Version{
@@ -48,19 +48,22 @@ func TestZIPWriterSystem(t *testing.T) {
 				Patch: 3,
 			}),
 		)
-		require.NoError(t, s.Read(ctx, nil))
+		assert.NoError(t, s.Read(ctx, nil))
 		requireEvaluateAll(t, s, system)
 
 		b := &bytes.Buffer{}
 		zipWriterSystem := NewZIPWriterSystem(b, time.Now().UTC())
 		persistentState := NewMockPersistentState()
-		require.NoError(t, s.applyAll(zipWriterSystem, system, persistentState, EmptyAbsPath, ApplyOptions{
-			Include: NewEntryTypeSet(EntryTypesAll),
-		}))
-		require.NoError(t, zipWriterSystem.Close())
+		assert.NoError(
+			t,
+			s.applyAll(zipWriterSystem, system, persistentState, EmptyAbsPath, ApplyOptions{
+				Filter: NewEntryTypeFilter(EntryTypesAll, EntryTypesNone),
+			}),
+		)
+		assert.NoError(t, zipWriterSystem.Close())
 
 		r, err := zip.NewReader(bytes.NewReader(b.Bytes()), int64(b.Len()))
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		expectedFiles := []struct {
 			name     string
 			method   uint16
@@ -69,7 +72,7 @@ func TestZIPWriterSystem(t *testing.T) {
 		}{
 			{
 				name: ".dir",
-				mode: (fs.ModeDir | 0o777) &^ chezmoitest.Umask,
+				mode: (fs.ModeDir | fs.ModePerm) &^ chezmoitest.Umask,
 			},
 			{
 				name:     ".dir/file",
@@ -89,7 +92,7 @@ func TestZIPWriterSystem(t *testing.T) {
 				contents: []byte(".dir/subdir/file"),
 			},
 		}
-		require.Len(t, r.File, len(expectedFiles))
+		assert.Equal(t, len(expectedFiles), len(r.File))
 		for i, expectedFile := range expectedFiles {
 			t.Run(expectedFile.name, func(t *testing.T) {
 				actualFile := r.File[i]
@@ -98,9 +101,9 @@ func TestZIPWriterSystem(t *testing.T) {
 				assert.Equal(t, expectedFile.mode, actualFile.Mode())
 				if expectedFile.contents != nil {
 					rc, err := actualFile.Open()
-					require.NoError(t, err)
+					assert.NoError(t, err)
 					actualContents, err := io.ReadAll(rc)
-					require.NoError(t, err)
+					assert.NoError(t, err)
 					assert.Equal(t, expectedFile.contents, actualContents)
 				}
 			})
