@@ -7,9 +7,8 @@ import (
 )
 
 type applyCmdConfig struct {
-	exclude   *chezmoi.EntryTypeSet
+	filter    *chezmoi.EntryTypeFilter
 	init      bool
-	include   *chezmoi.EntryTypeSet
 	recursive bool
 }
 
@@ -21,24 +20,34 @@ func (c *Config) newApplyCmd() *cobra.Command {
 		Example:           example("apply"),
 		ValidArgsFunction: c.targetValidArgs,
 		RunE:              c.runApplyCmd,
-		Annotations: map[string]string{
-			modifiesDestinationDirectory: "true",
-			persistentStateMode:          persistentStateModeReadWrite,
-		},
+		Annotations: newAnnotations(
+			modifiesDestinationDirectory,
+			persistentStateModeReadWrite,
+			requiresSourceDirectory,
+		),
 	}
 
 	flags := applyCmd.Flags()
-	flags.VarP(c.apply.exclude, "exclude", "x", "Exclude entry types")
-	flags.VarP(c.apply.include, "include", "i", "Include entry types")
-	flags.BoolVar(&c.apply.init, "init", c.update.init, "Recreate config file from template")
-	flags.BoolVarP(&c.apply.recursive, "recursive", "r", c.apply.recursive, "Recurse into subdirectories")
+	flags.VarP(c.apply.filter.Exclude, "exclude", "x", "Exclude entry types")
+	flags.VarP(c.apply.filter.Include, "include", "i", "Include entry types")
+	flags.BoolVar(&c.apply.init, "init", c.apply.init, "Recreate config file from template")
+	flags.BoolVarP(
+		&c.apply.recursive,
+		"recursive",
+		"r",
+		c.apply.recursive,
+		"Recurse into subdirectories",
+	)
+
+	registerExcludeIncludeFlagCompletionFuncs(applyCmd)
 
 	return applyCmd
 }
 
 func (c *Config) runApplyCmd(cmd *cobra.Command, args []string) error {
 	return c.applyArgs(cmd.Context(), c.destSystem, c.DestDirAbsPath, args, applyArgsOptions{
-		include:      c.apply.include.Sub(c.apply.exclude),
+		cmd:          cmd,
+		filter:       c.apply.filter,
 		init:         c.apply.init,
 		recursive:    c.apply.recursive,
 		umask:        c.Umask,
