@@ -7,23 +7,52 @@ import (
 	"strings"
 
 	"github.com/mitchellh/mapstructure"
+
+	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
 )
 
 type autoBool struct {
-	auto     bool
-	value    bool
-	valueErr error
+	auto  bool
+	value bool
+}
+
+// autoBoolFlagCompletionFunc is a function that completes the value of autoBool
+// flags.
+var autoBoolFlagCompletionFunc = chezmoi.FlagCompletionFunc([]string{
+	"1", "t", "T", "true", "TRUE", "True",
+	"0", "f", "F", "false", "FALSE", "False",
+	"auto", "AUTO", "Auto",
+})
+
+// MarshalJSON implements encoding/json.Marshaler.MarshalJSON.
+func (b autoBool) MarshalJSON() ([]byte, error) {
+	switch {
+	case b.auto:
+		return []byte(`"auto"`), nil
+	case b.value:
+		return []byte(`true`), nil
+	default:
+		return []byte(`false`), nil
+	}
+}
+
+// MarshalYAML implements gopkg.in/yaml.v3.Marshaler.
+func (b autoBool) MarshalYAML() (any, error) {
+	if b.auto {
+		return "auto", nil
+	}
+	return b.value, nil
 }
 
 // Set implements github.com/spf13/pflag.Value.Set.
 func (b *autoBool) Set(s string) error {
-	if strings.ToLower(s) == "auto" {
+	if strings.EqualFold(s, "auto") {
 		b.auto = true
 		return nil
 	}
 	b.auto = false
 	var err error
-	b.value, err = parseBool(s)
+	b.value, err = chezmoi.ParseBool(s)
 	if err != nil {
 		return err
 	}
@@ -43,19 +72,19 @@ func (b *autoBool) Type() string {
 }
 
 // Value returns b's value, calling b's autoFunc if needed.
-func (b *autoBool) Value(autoFunc func() (bool, error)) (bool, error) {
+func (b *autoBool) Value(autoFunc func() bool) bool {
 	if b.auto {
-		b.value, b.valueErr = autoFunc()
+		b.value = autoFunc()
 		b.auto = false
 	}
-	return b.value, b.valueErr
+	return b.value
 }
 
 // StringOrBoolToAutoBoolHookFunc is a
 // github.com/mitchellh/mapstructure.DecodeHookFunc that parses an autoBool from
 // a bool or string.
 func StringOrBoolToAutoBoolHookFunc() mapstructure.DecodeHookFunc {
-	return func(from, to reflect.Type, data interface{}) (interface{}, error) {
+	return func(from, to reflect.Type, data any) (any, error) {
 		if to != reflect.TypeOf(autoBool{}) {
 			return data, nil
 		}
