@@ -37,6 +37,7 @@ import (
 	"github.com/rs/zerolog/log"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
+	"github.com/twpayne/go-shell"
 	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-xdg/v6"
 	cobracompletefig "github.com/withfig/autocomplete-tools/integrations/cobra"
@@ -51,7 +52,6 @@ import (
 	"github.com/twpayne/chezmoi/v2/internal/chezmoierrors"
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 	"github.com/twpayne/chezmoi/v2/internal/git"
-	"github.com/twpayne/chezmoi/v2/internal/shell"
 )
 
 // defaultSentinel is a string value used to indicate that the default value
@@ -249,27 +249,29 @@ type Config struct {
 }
 
 type templateData struct {
-	arch           string
-	args           []string
-	cacheDir       chezmoi.AbsPath
-	command        string
-	config         map[string]any
-	configFile     chezmoi.AbsPath
-	executable     chezmoi.AbsPath
-	fqdnHostname   string
-	gid            string
-	group          string
-	homeDir        chezmoi.AbsPath
-	hostname       string
-	kernel         map[string]any
-	os             string
-	osRelease      map[string]any
-	sourceDir      chezmoi.AbsPath
-	uid            string
-	username       string
-	version        map[string]any
-	windowsVersion map[string]any
-	workingTree    chezmoi.AbsPath
+	arch              string
+	args              []string
+	cacheDir          chezmoi.AbsPath
+	command           string
+	config            map[string]any
+	configFile        chezmoi.AbsPath
+	executable        chezmoi.AbsPath
+	fqdnHostname      string
+	gid               string
+	group             string
+	homeDir           chezmoi.AbsPath
+	hostname          string
+	kernel            map[string]any
+	os                string
+	osRelease         map[string]any
+	pathListSeparator string
+	pathSeparator     string
+	sourceDir         chezmoi.AbsPath
+	uid               string
+	username          string
+	version           map[string]any
+	windowsVersion    map[string]any
+	workingTree       chezmoi.AbsPath
 }
 
 // A configOption sets and option on a Config.
@@ -408,6 +410,8 @@ func newConfig(options ...configOption) (*Config, error) {
 		"ejsonDecryptWithKey":      c.ejsonDecryptWithKeyTemplateFunc,
 		"encrypt":                  c.encryptTemplateFunc,
 		"eqFold":                   c.eqFoldTemplateFunc,
+		"findExecutable":           c.findExecutableTemplateFunc,
+		"findOneExecutable":        c.findOneExecutableTemplateFunc,
 		"fromIni":                  c.fromIniTemplateFunc,
 		"fromJsonc":                c.fromJsoncTemplateFunc,
 		"fromToml":                 c.fromTomlTemplateFunc,
@@ -450,8 +454,8 @@ func newConfig(options ...configOption) (*Config, error) {
 		"output":                   c.outputTemplateFunc,
 		"pass":                     c.passTemplateFunc,
 		"passFields":               c.passFieldsTemplateFunc,
-		"passRaw":                  c.passRawTemplateFunc,
 		"passhole":                 c.passholeTemplateFunc,
+		"passRaw":                  c.passRawTemplateFunc,
 		"pruneEmptyDicts":          c.pruneEmptyDictsTemplateFunc,
 		"quoteList":                c.quoteListTemplateFunc,
 		"rbw":                      c.rbwTemplateFunc,
@@ -1393,27 +1397,29 @@ func (c *Config) getTemplateDataMap(cmd *cobra.Command) map[string]any {
 
 	return map[string]any{
 		"chezmoi": map[string]any{
-			"arch":           templateData.arch,
-			"args":           templateData.args,
-			"cacheDir":       templateData.cacheDir.String(),
-			"command":        templateData.command,
-			"config":         templateData.config,
-			"configFile":     templateData.configFile.String(),
-			"executable":     templateData.executable.String(),
-			"fqdnHostname":   templateData.fqdnHostname,
-			"gid":            templateData.gid,
-			"group":          templateData.group,
-			"homeDir":        templateData.homeDir.String(),
-			"hostname":       templateData.hostname,
-			"kernel":         templateData.kernel,
-			"os":             templateData.os,
-			"osRelease":      templateData.osRelease,
-			"sourceDir":      templateData.sourceDir.String(),
-			"uid":            templateData.uid,
-			"username":       templateData.username,
-			"version":        templateData.version,
-			"windowsVersion": templateData.windowsVersion,
-			"workingTree":    templateData.workingTree.String(),
+			"arch":              templateData.arch,
+			"args":              templateData.args,
+			"cacheDir":          templateData.cacheDir.String(),
+			"command":           templateData.command,
+			"config":            templateData.config,
+			"configFile":        templateData.configFile.String(),
+			"executable":        templateData.executable.String(),
+			"fqdnHostname":      templateData.fqdnHostname,
+			"gid":               templateData.gid,
+			"group":             templateData.group,
+			"homeDir":           templateData.homeDir.String(),
+			"hostname":          templateData.hostname,
+			"kernel":            templateData.kernel,
+			"os":                templateData.os,
+			"osRelease":         templateData.osRelease,
+			"pathListSeparator": templateData.pathListSeparator,
+			"pathSeparator":     templateData.pathSeparator,
+			"sourceDir":         templateData.sourceDir.String(),
+			"uid":               templateData.uid,
+			"username":          templateData.username,
+			"version":           templateData.version,
+			"windowsVersion":    templateData.windowsVersion,
+			"workingTree":       templateData.workingTree.String(),
 		},
 	}
 }
@@ -1986,7 +1992,9 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		c.sourceSystem = chezmoi.NewDryRunSystem(c.sourceSystem)
 		c.destSystem = chezmoi.NewDryRunSystem(c.destSystem)
 	}
-	if c.Verbose || annotations.hasTag(outputsDiff) {
+	if annotations.hasTag(outputsDiff) ||
+		c.Verbose &&
+			(annotations.hasTag(modifiesDestinationDirectory) || annotations.hasTag(modifiesSourceDirectory)) {
 		// If the user has configured a diff pager, then start it as a process.
 		// Otherwise, write the diff output directly to stdout.
 		var writer io.Writer
@@ -2261,24 +2269,26 @@ func (c *Config) newTemplateData(cmd *cobra.Command) *templateData {
 	sourceDirAbsPath, _ := c.getSourceDirAbsPath(nil)
 
 	return &templateData{
-		arch:         runtime.GOARCH,
-		args:         os.Args,
-		cacheDir:     c.CacheDirAbsPath,
-		command:      cmd.Name(),
-		config:       c.ConfigFile.toMap(),
-		configFile:   c.configFileAbsPath,
-		executable:   chezmoi.NewAbsPath(executable),
-		fqdnHostname: fqdnHostname,
-		gid:          gid,
-		group:        group,
-		homeDir:      c.homeDirAbsPath,
-		hostname:     hostname,
-		kernel:       kernel,
-		os:           runtime.GOOS,
-		osRelease:    osRelease,
-		sourceDir:    sourceDirAbsPath,
-		uid:          uid,
-		username:     username,
+		arch:              runtime.GOARCH,
+		args:              os.Args,
+		cacheDir:          c.CacheDirAbsPath,
+		command:           cmd.Name(),
+		config:            c.ConfigFile.toMap(),
+		configFile:        c.configFileAbsPath,
+		executable:        chezmoi.NewAbsPath(executable),
+		fqdnHostname:      fqdnHostname,
+		gid:               gid,
+		group:             group,
+		homeDir:           c.homeDirAbsPath,
+		hostname:          hostname,
+		kernel:            kernel,
+		os:                runtime.GOOS,
+		osRelease:         osRelease,
+		pathListSeparator: string(os.PathListSeparator),
+		pathSeparator:     string(os.PathSeparator),
+		sourceDir:         sourceDirAbsPath,
+		uid:               uid,
+		username:          username,
 		version: map[string]any{
 			"builtBy": c.versionInfo.BuiltBy,
 			"commit":  c.versionInfo.Commit,
